@@ -56,7 +56,7 @@ Puppet::Type.newtype(:nova_flavor) do
   ensurable
 
   autorequire(:nova_config) do
-    ['www_authenticate_uri', 'project_name', 'username', 'password']
+    ['auth_url', 'project_name', 'username', 'password']
   end
 
   # Require the nova-api service to be running
@@ -151,4 +151,3 @@ Puppet::Type.newtype(:nova_flavor) do
   end
 
 end
-
