@@ -50,20 +50,12 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with('value' => '8774')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen').with('value' => '0.0.0.0')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with('value' => '8775')
-        is_expected.to contain_nova_config('DEFAULT/osapi_volume_listen').with('value' => '0.0.0.0')
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '5')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '5')
-        is_expected.to contain_nova_config('api/fping_path').with('value' => '/usr/sbin/fping')
         is_expected.to contain_oslo__middleware('nova_config').with(
           :enable_proxy_headers_parsing => '<SERVICE DEFAULT>',
+          :max_request_body_size        => '<SERVICE DEFAULT>',
         )
-        is_expected.to contain_nova_config('api/metadata_cache_expiration').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/vendordata_jsonfile_path').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/vendordata_providers').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/vendordata_dynamic_targets').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/vendordata_dynamic_connect_timeout').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/vendordata_dynamic_read_timeout').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('api/vendordata_dynamic_failure_fatal').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/max_limit').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/compute_link_prefix').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('api/glance_link_prefix').with('value' => '<SERVICE DEFAULT>')
@@ -73,61 +65,33 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('api/enable_instance_password').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with('value' => false)
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/auth_type').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/auth_url').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/os_region_name').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/password').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/project_domain_name').with('value' => 'Default')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/project_name').with('value' => '<SERVICE DEFAULT>')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/user_domain_name').with('value' => 'Default')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/username').with('value' => '<SERVICE DEFAULT>')
-      end
-
-      it 'unconfigures neutron_metadata proxy' do
-        is_expected.to contain_nova_config('neutron/service_metadata_proxy').with(:value => false)
-        is_expected.to contain_nova_config('neutron/metadata_proxy_shared_secret').with(:ensure => 'absent')
       end
     end
 
     context 'with overridden parameters' do
       before do
         params.merge!({
-          :enabled                                     => false,
-          :ensure_package                              => '2012.1-2',
-          :api_bind_address                            => '192.168.56.210',
-          :metadata_listen                             => '127.0.0.1',
-          :metadata_listen_port                        => 8875,
-          :osapi_compute_listen_port                   => 8874,
-          :use_forwarded_for                           => false,
-          :ratelimits                                  => '(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)',
-          :neutron_metadata_proxy_shared_secret        => 'secrete',
-          :osapi_compute_workers                       => 1,
-          :metadata_workers                            => 2,
-          :enable_proxy_headers_parsing                => true,
-          :metadata_cache_expiration                   => 15,
-          :vendordata_jsonfile_path                    => '/tmp',
-          :vendordata_providers                        => ['StaticJSON', 'DynamicJSON'],
-          :vendordata_dynamic_targets                  => ['join@http://127.0.0.1:9999/v1/'],
-          :vendordata_dynamic_connect_timeout          => 30,
-          :vendordata_dynamic_read_timeout             => 30,
-          :vendordata_dynamic_failure_fatal            => false,
-          :max_limit                                   => 1000,
-          :compute_link_prefix                         => 'https://10.0.0.1:7777/',
-          :glance_link_prefix                          => 'https://10.0.0.1:6666/',
-          :hide_server_address_states                  => 'building',
-          :allow_instance_snapshots                    => true,
-          :enable_network_quota                        => false,
-          :enable_instance_password                    => true,
-          :password_length                             => 12,
-          :allow_resize_to_same_host                   => true,
-          :vendordata_dynamic_auth_auth_type           => 'password',
-          :vendordata_dynamic_auth_auth_url            => 'http://127.0.0.1:5000',
-          :vendordata_dynamic_auth_os_region_name      => 'RegionOne',
-          :vendordata_dynamic_auth_password            => 'secrete',
-          :vendordata_dynamic_auth_project_domain_name => 'Default',
-          :vendordata_dynamic_auth_project_name        => 'project',
-          :vendordata_dynamic_auth_user_domain_name    => 'Default',
-          :vendordata_dynamic_auth_username            => 'user',
+          :enabled                      => false,
+          :ensure_package               => '2012.1-2',
+          :api_bind_address             => '192.168.56.210',
+          :metadata_listen              => '127.0.0.1',
+          :metadata_listen_port         => 8875,
+          :osapi_compute_listen_port    => 8874,
+          :use_forwarded_for            => false,
+          :ratelimits                   => '(GET, "*", .*, 100, MINUTE);(POST, "*", .*, 200, MINUTE)',
+          :osapi_compute_workers        => 1,
+          :metadata_workers             => 2,
+          :enable_proxy_headers_parsing => true,
+          :max_request_body_size        => '102400',
+          :max_limit                    => 1000,
+          :compute_link_prefix          => 'https://10.0.0.1:7777/',
+          :glance_link_prefix           => 'https://10.0.0.1:6666/',
+          :hide_server_address_states   => 'building',
+          :allow_instance_snapshots     => true,
+          :enable_network_quota         => false,
+          :enable_instance_password     => true,
+          :password_length              => 12,
+          :allow_resize_to_same_host    => true,
         })
       end
 
@@ -151,24 +115,15 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_listen_port').with('value' => '8874')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen').with('value' => '127.0.0.1')
         is_expected.to contain_nova_config('DEFAULT/metadata_listen_port').with('value' => '8875')
-        is_expected.to contain_nova_config('DEFAULT/osapi_volume_listen').with('value' => '192.168.56.210')
         is_expected.to contain_nova_config('api/use_forwarded_for').with('value' => false)
         is_expected.to contain_nova_config('DEFAULT/osapi_compute_workers').with('value' => '1')
         is_expected.to contain_nova_config('DEFAULT/metadata_workers').with('value' => '2')
-        is_expected.to contain_nova_config('api/metadata_cache_expiration').with('value' => '15')
-        is_expected.to contain_nova_config('api/vendordata_jsonfile_path').with('value' => '/tmp')
-        is_expected.to contain_nova_config('api/vendordata_providers').with('value' => 'StaticJSON,DynamicJSON')
-        is_expected.to contain_nova_config('api/vendordata_dynamic_targets').with('value' => 'join@http://127.0.0.1:9999/v1/')
-        is_expected.to contain_nova_config('api/vendordata_dynamic_connect_timeout').with('value' => '30')
-        is_expected.to contain_nova_config('api/vendordata_dynamic_read_timeout').with('value' => '30')
-        is_expected.to contain_nova_config('api/vendordata_dynamic_failure_fatal').with('value' => false)
         is_expected.to contain_nova_config('api/max_limit').with('value' => '1000')
         is_expected.to contain_nova_config('api/compute_link_prefix').with('value' => 'https://10.0.0.1:7777/')
         is_expected.to contain_nova_config('api/glance_link_prefix').with('value' => 'https://10.0.0.1:6666/')
-        is_expected.to contain_nova_config('neutron/service_metadata_proxy').with('value' => true)
-        is_expected.to contain_nova_config('neutron/metadata_proxy_shared_secret').with('value' => 'secrete').with_secret(true)
         is_expected.to contain_oslo__middleware('nova_config').with(
           :enable_proxy_headers_parsing => true,
+          :max_request_body_size        => '102400',
         )
         is_expected.to contain_nova_config('api/hide_server_address_states').with('value' => 'building')
         is_expected.to contain_nova_config('api/allow_instance_snapshots').with('value' => true)
@@ -176,14 +131,6 @@ describe 'nova::api' do
         is_expected.to contain_nova_config('api/enable_instance_password').with('value' => true)
         is_expected.to contain_nova_config('DEFAULT/password_length').with('value' => '12')
         is_expected.to contain_nova_config('DEFAULT/allow_resize_to_same_host').with('value' => true)
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/auth_type').with('value' => 'password')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/auth_url').with('value' => 'http://127.0.0.1:5000')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/os_region_name').with('value' => 'RegionOne')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/password').with('value' => 'secrete').with_secret(true)
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/project_domain_name').with('value' => 'Default')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/project_name').with('value' => 'project')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/user_domain_name').with('value' => 'Default')
-        is_expected.to contain_nova_config('vendordata_dynamic_auth/username').with('value' => 'user')
       end
     end
 
@@ -236,7 +183,7 @@ describe 'nova::api' do
       it { is_expected.to_not contain_nova_config('database/slave_connection') }
       it { is_expected.to_not contain_nova_config('api_database/connection') }
       it { is_expected.to_not contain_nova_config('api_database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('database/idle_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to_not contain_nova_config('database/connection_recycle_time').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with overridden database parameters' do
@@ -257,9 +204,9 @@ describe 'nova::api' do
       it { is_expected.to contain_nova_config('api_database/connection').with_value('mysql://user:pass@db/db2').with_secret(true) }
       it { is_expected.to contain_nova_config('api_database/slave_connection').with_value('mysql://user:pass@slave/db2').with_secret(true) }
       it { is_expected.to contain_oslo__db('nova_config').with(
-        :connection       => 'mysql://user:pass@db/db1',
-        :slave_connection => 'mysql://user:pass@slave/db1',
-        :idle_timeout     => '30',
+        :connection              => 'mysql://user:pass@db/db1',
+        :slave_connection        => 'mysql://user:pass@slave/db1',
+        :connection_recycle_time => '30',
       )}
     end
 
@@ -325,6 +272,32 @@ describe 'nova::api' do
       end
     end
 
+    context 'when running nova API in wsgi for compute, and metadata in wsgi' do
+      before do
+        params.merge!({
+          :service_name => 'httpd',
+          :nova_metadata_wsgi_enabled => true })
+      end
+
+      let :pre_condition do
+        "include ::apache
+         include ::nova
+         class { '::nova::keystone::authtoken':
+           password => 'a_big_secret',
+         }"
+      end
+
+      it 'disable nova API service' do
+          is_expected.to contain_service('nova-api').with(
+          :ensure => 'stopped',
+          :name   => platform_params[:nova_api_service],
+          :enable => false,
+          :tag    => 'nova-service',
+        )
+      end
+
+    end
+
     context 'when disabling cinder client installation' do
       before do
         params.merge!({ :install_cinder_client => false })
@@ -352,6 +325,18 @@ describe 'nova::api' do
 
   end
 
+  shared_examples 'nova-api on Debian' do
+    context 'with default parameters' do
+      it { is_expected.to contain_service('nova-api- metadata').with(
+        :name      => 'nova-api-metadata',
+        :ensure    => 'running',
+        :hasstatus => true,
+        :enable    => true,
+        :tag       => 'nova-service',
+      )}
+    end
+  end
+
   on_supported_os({
     :supported_os => OSDefaults.get_supported_os
   }).each do |os,facts|
@@ -371,6 +356,9 @@ describe 'nova::api' do
         end
       end
       it_behaves_like 'nova-api'
+      if facts[:os_package_type] == 'debian'
+        it_behaves_like 'nova-api on Debian'
+      end
     end
   end
 end
