@@ -5,6 +5,7 @@ describe 'nova::client' do
   shared_examples_for 'nova client' do
 
     it { is_expected.to contain_class('nova::deps') }
+    it { is_expected.to contain_class('nova::params') }
 
     it 'installs nova client package' do
       is_expected.to contain_package('python-novaclient').with(
@@ -26,11 +27,7 @@ describe 'nova::client' do
       let(:platform_params) do
         case facts[:osfamily]
         when 'Debian'
-          if facts[:os_package_type] == 'debian'
-            { :client_package_name => 'python3-novaclient' }
-          else
-            { :client_package_name => 'python-novaclient' }
-          end
+          { :client_package_name => 'python3-novaclient' }
         when 'RedHat'
           { :client_package_name => 'python-novaclient' }
         end
