@@ -58,13 +58,18 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
-      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('127.0.0.1')}
+      it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_ensure('absent')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value('<SERVICE DEFAULT>')}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_ensure('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_ensure('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value('<SERVICE DEFAULT>')}
+      it { is_expected.to contain_libvirtd_config('log_filters').with_ensure('absent')}
+      it { is_expected.to contain_libvirtd_config('tls_priority').with_ensure('absent')}
     end
 
     describe 'with params' do
@@ -92,6 +97,11 @@ describe 'nova::compute::libvirt' do
           :rx_queue_size                              => 512,
           :tx_queue_size                              => 1024,
           :volume_use_multipath                       => false,
+          :nfs_mount_options                          => 'rw,intr,nolock',
+          :num_pcie_ports                             => 16,
+          :mem_stats_period_seconds                   => 20,
+          :log_filters                                => '1:qemu',
+          :tls_priority                               => 'NORMAL:-VERS-SSL3.0',
         }
       end
 
@@ -110,7 +120,7 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/hw_disk_discard').with_value('unmap')}
       it { is_expected.to contain_nova_config('libvirt/hw_machine_type').with_value('x86_64=machinetype1,armv7l=machinetype2')}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('cmt,mbml,mbmt')}
-      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
+      it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value(true)}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value(3600)}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_value(3600)}
@@ -118,6 +128,11 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/rx_queue_size').with_value(512)}
       it { is_expected.to contain_nova_config('libvirt/tx_queue_size').with_value(1024)}
       it { is_expected.to contain_nova_config('libvirt/volume_use_multipath').with_value(false)}
+      it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
+      it { is_expected.to contain_nova_config('libvirt/num_pcie_ports').with_value(16)}
+      it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value(20)}
+      it { is_expected.to contain_libvirtd_config('log_filters').with_value("\"#{params[:log_filters]}\"")}
+      it { is_expected.to contain_libvirtd_config('tls_priority').with_value("\"#{params[:tls_priority]}\"")}
       it {
         is_expected.to contain_service('libvirt').with(
           :name     => 'custom_service',
@@ -176,7 +191,7 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
-        it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
+        it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
         it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
@@ -191,7 +206,7 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
-        it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('::0')}
+        it { is_expected.to contain_nova_config('vnc/server_listen').with_value('::0')}
         it { is_expected.to contain_file_line('/etc/default/libvirtd libvirtd opts').with(:line => libvirt_options) }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
@@ -282,10 +297,11 @@ describe 'nova::compute::libvirt' do
       it { is_expected.to contain_nova_config('libvirt/inject_password').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_key').with_value(false)}
       it { is_expected.to contain_nova_config('libvirt/inject_partition').with_value(-2)}
-      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('127.0.0.1')}
+      it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_ensure('absent')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_ensure('absent')}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_ensure('absent')}
+      it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_ensure('<SERVICE DEFAULT>')}
     end
 
     describe 'with params' do
@@ -295,16 +311,20 @@ describe 'nova::compute::libvirt' do
           :remove_unused_base_images                  => true,
           :remove_unused_resized_minimum_age_seconds  => 3600,
           :remove_unused_original_minimum_age_seconds => 3600,
-          :libvirt_enabled_perf_events                => ['cmt', 'mbml', 'mbmt']
+          :libvirt_enabled_perf_events                => ['cmt', 'mbml', 'mbmt'],
+          :nfs_mount_options                          => 'rw,intr,nolock',
+          :mem_stats_period_seconds                   => 20,
         }
       end
 
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('qemu')}
-      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
+      it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_base_images').with_value(true)}
       it { is_expected.to contain_nova_config('DEFAULT/remove_unused_original_minimum_age_seconds').with_value(3600)}
       it { is_expected.to contain_nova_config('libvirt/remove_unused_resized_minimum_age_seconds').with_value(3600)}
       it { is_expected.to contain_nova_config('libvirt/enabled_perf_events').with_value('cmt,mbml,mbmt')}
+      it { is_expected.to contain_nova_config('libvirt/nfs_mount_options').with_value('rw,intr,nolock')}
+      it { is_expected.to contain_nova_config('libvirt/mem_stats_period_seconds').with_value(20)}
       it { is_expected.to contain_package('libvirt').with(
         :name   => 'libvirt-daemon-kvm',
         :ensure => 'present'
@@ -320,7 +340,7 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
-        it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('0.0.0.0')}
+        it { is_expected.to contain_nova_config('vnc/server_listen').with_value('0.0.0.0')}
         it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
@@ -335,7 +355,7 @@ describe 'nova::compute::libvirt' do
         end
 
         it { is_expected.to contain_class('nova::migration::libvirt')}
-        it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('::0')}
+        it { is_expected.to contain_nova_config('vnc/server_listen').with_value('::0')}
         it { is_expected.to contain_file_line('/etc/sysconfig/libvirtd libvirtd args').with(:line => 'LIBVIRTD_ARGS="--listen"') }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tls').with(:line => "listen_tls = 0") }
         it { is_expected.to contain_file_line('/etc/libvirt/libvirtd.conf listen_tcp').with(:line => "listen_tcp = 1") }
@@ -387,7 +407,7 @@ describe 'nova::compute::libvirt' do
 
       it { is_expected.to contain_nova_config('DEFAULT/compute_driver').with_value('libvirt.LibvirtDriver')}
       it { is_expected.to contain_nova_config('libvirt/virt_type').with_value('kvm')}
-      it { is_expected.to contain_nova_config('vnc/vncserver_listen').with_value('127.0.0.1')}
+      it { is_expected.to contain_nova_config('vnc/server_listen').with_value('127.0.0.1')}
     end
 
   end
