@@ -30,7 +30,7 @@ describe 'nova::db::postgresql_api' do
     context "on #{os}" do
       let (:facts) do
         facts.merge(OSDefaults.get_facts({
-          :processorcount => 8,
+          :os_workers     => 8,
           :concat_basedir => '/var/lib/puppet/concat'
         }))
       end
