@@ -6,10 +6,6 @@ describe 'nova' do
 
     context 'with default parameters' do
 
-     it 'contains the logging class' do
-       is_expected.to contain_class('nova::logging')
-     end
-
       it 'installs packages' do
         is_expected.to contain_package('python-nova').with(
           :ensure => 'present',
@@ -31,8 +27,7 @@ describe 'nova' do
         :refreshonly => true
       )}
 
-      it 'configures image service' do
-        is_expected.to contain_nova_config('DEFAULT/image_service').with_value('nova.image.glance.GlanceImageService')
+      it 'configures glance api servers' do
         is_expected.to contain_nova_config('glance/api_servers').with_value('http://localhost:9292')
       end
 
@@ -45,6 +40,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures various things' do
@@ -53,15 +49,19 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/service_down_time').with_value('60')
         is_expected.to contain_nova_config('DEFAULT/rootwrap_config').with_value('/etc/nova/rootwrap.conf')
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('10')
-        is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/transport_url').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/rpc_response_timeout').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('cinder/cross_az_attach').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('cinder/catalog_info').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/cpu_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/ram_allocation_ratio').with_value('<SERVICE DEFAULT>')
         is_expected.to contain_nova_config('DEFAULT/disk_allocation_ratio').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(false)
+        is_expected.to contain_nova_config('DEFAULT/cert').with_value('<SERVICE DEFAULT>')
+        is_expected.to contain_nova_config('DEFAULT/key').with_value('<SERVICE DEFAULT>')
       end
 
       it 'configures block_device_allocate params' do
@@ -73,14 +73,14 @@ describe 'nova' do
     context 'with overridden parameters' do
 
       let :params do
-        { :debug                                   => true,
-          :log_dir                                 => '/var/log/nova2',
-          :image_service                           => 'nova.image.local.LocalImageService',
+        {
+          :glance_api_servers                      => 'http://localhost:9292',
           :default_transport_url                   => 'rabbit://rabbit_user:password@localhost:5673',
           :rpc_response_timeout                    => '30',
           :control_exchange                        => 'nova',
           :rabbit_heartbeat_timeout_threshold      => '60',
           :rabbit_heartbeat_rate                   => '10',
+          :rabbit_heartbeat_in_pthread             => true,
           :lock_path                               => '/var/locky/path',
           :state_path                              => '/var/lib/nova2',
           :service_down_time                       => '120',
@@ -91,16 +91,15 @@ describe 'nova' do
           :notification_driver                     => 'ceilometer.compute.nova_notifier',
           :notification_topics                     => 'openstack',
           :notification_format                     => 'unversioned',
-          :notify_on_api_faults                    => true,
           :report_interval                         => '60',
           :os_region_name                          => 'MyRegion',
-          :use_ipv6                                => true,
+          :cross_az_attach                         => 'MyAZ',
+          :ovsdb_connection                        => 'tcp:127.0.0.1:6640',
           :upgrade_level_cells                     => '1.0.0',
           :upgrade_level_cert                      => '1.0.0',
           :upgrade_level_compute                   => '1.0.0',
           :upgrade_level_conductor                 => '1.0.0',
           :upgrade_level_console                   => '1.0.0',
-          :upgrade_level_consoleauth               => '1.0.0',
           :upgrade_level_intercell                 => '1.0.0',
           :upgrade_level_network                   => '1.0.0',
           :upgrade_level_scheduler                 => '1.0.0',
@@ -108,6 +107,9 @@ describe 'nova' do
           :block_device_allocate_retries           => '60',
           :block_device_allocate_retries_interval  => '3',
           :my_ip                                   => '192.0.2.1',
+          :ssl_only                                => true,
+          :cert                                    => '/etc/ssl/private/snakeoil.pem',
+          :key                                     => '/etc/ssl/certs/snakeoil.pem',
         }
       end
 
@@ -122,9 +124,8 @@ describe 'nova' do
         })
       end
 
-      it 'configures image service' do
-        is_expected.to contain_nova_config('DEFAULT/image_service').with_value('nova.image.local.LocalImageService')
-        is_expected.to_not contain_nova_config('glance/api_servers')
+      it 'configures glance api servers' do
+        is_expected.to contain_nova_config('glance/api_servers')
       end
 
       it 'configures auth_strategy' do
@@ -138,6 +139,7 @@ describe 'nova' do
         is_expected.to contain_nova_config('DEFAULT/control_exchange').with_value('nova')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_timeout_threshold').with_value('60')
         is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_rate').with_value('10')
+        is_expected.to contain_nova_config('oslo_messaging_rabbit/heartbeat_in_pthread').with_value(true)
       end
 
       it 'configures host' do
@@ -154,7 +156,6 @@ describe 'nova' do
         is_expected.to contain_nova_config('upgrade_levels/compute').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/conductor').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/console').with_value('1.0.0')
-        is_expected.to contain_nova_config('upgrade_levels/consoleauth').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/intercell').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/network').with_value('1.0.0')
         is_expected.to contain_nova_config('upgrade_levels/scheduler').with_value('1.0.0')
@@ -169,10 +170,13 @@ describe 'nova' do
         is_expected.to contain_nova_config('oslo_messaging_notifications/driver').with_value('ceilometer.compute.nova_notifier')
         is_expected.to contain_nova_config('oslo_messaging_notifications/topics').with_value('openstack')
         is_expected.to contain_nova_config('notifications/notification_format').with_value('unversioned')
-        is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value(true)
         is_expected.to contain_nova_config('DEFAULT/report_interval').with_value('60')
-        is_expected.to contain_nova_config('os_vif_linux_bridge/use_ipv6').with_value('true')
+        is_expected.to contain_nova_config('DEFAULT/ovsdb_connection').with_value('tcp:127.0.0.1:6640')
         is_expected.to contain_nova_config('cinder/os_region_name').with_value('MyRegion')
+        is_expected.to contain_nova_config('cinder/cross_az_attach').with_value('MyAZ')
+        is_expected.to contain_nova_config('DEFAULT/ssl_only').with_value(true)
+        is_expected.to contain_nova_config('DEFAULT/cert').with_value('/etc/ssl/private/snakeoil.pem')
+        is_expected.to contain_nova_config('DEFAULT/key').with_value('/etc/ssl/certs/snakeoil.pem')
       end
 
       context 'with multiple notification_driver' do
@@ -209,17 +213,6 @@ describe 'nova' do
       end
     end
 
-    context 'with deprecated notify_api_faults parameter' do
-      let :params do
-        { :notify_on_api_faults => :undef,
-          :notify_api_faults    => 'true' }
-      end
-
-      it 'configures notify_on_api_faults using the deprecated parameter' do
-        is_expected.to contain_nova_config('notifications/notify_on_api_faults').with_value('true')
-      end
-    end
-
     context 'with kombu_reconnect_delay set to 5.0' do
       let :params do
         { :kombu_reconnect_delay => '5.0' }
