@@ -19,7 +19,7 @@ describe 'nova::metadata::novajoin::api' do
       :manage_service            => true,
       :service_user              => 'novajoin',
       :project_domain_name       => 'default',
-      :project_name              => 'service',
+      :project_name              => 'services',
       :user_domain_id            => 'default',
       :ipa_domain                => 'EXAMPLE.COM',
       :keystone_auth_url         => 'https://keystone.example.com:5000',
@@ -54,7 +54,7 @@ describe 'nova::metadata::novajoin::api' do
        :manage_service            => true,
        :service_user              => 'novajoin1',
        :project_domain_name       => 'default',
-       :project_name              => 'service',
+       :project_name              => 'services',
        :user_domain_id            => 'default',
        :ipa_domain                => 'EXAMPLE2.COM',
        :keystone_auth_url         => 'https://keystone2.example.com:5000',
