@@ -22,6 +22,8 @@ describe 'nova::scheduler' do
     it { is_expected.to contain_nova_config('scheduler/workers').with_value(4) }
     it { is_expected.to contain_nova_config('scheduler/driver').with_value('filter_scheduler') }
     it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/query_placement_for_image_type_support').with_value('<SERVICE DEFAULT>') }
+    it { is_expected.to contain_nova_config('scheduler/limit_tenants_to_placement_aggregate').with_value('<SERVICE DEFAULT>')}
 
     context 'with manage_service as false' do
       let :params do
@@ -66,6 +68,22 @@ describe 'nova::scheduler' do
       it { is_expected.to contain_nova_config('scheduler/discover_hosts_in_cells_interval').with_value(15) }
     end
 
+    context 'with query_placement_for_image_type_support' do
+      let :params do
+        { :query_placement_for_image_type_support => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/query_placement_for_image_type_support').with_value(true) }
+    end
+
+    context 'with limit_tenants_to_placement_aggregate' do
+      let :params do
+        { :limit_tenants_to_placement_aggregate => true }
+      end
+
+      it { is_expected.to contain_nova_config('scheduler/limit_tenants_to_placement_aggregate').with_value(true) }
+    end
+
     context 'with default database parameters' do
       let :pre_condition do
         "include nova"
@@ -73,7 +91,7 @@ describe 'nova::scheduler' do
 
       it { is_expected.to_not contain_nova_config('database/connection') }
       it { is_expected.to_not contain_nova_config('database/slave_connection') }
-      it { is_expected.to_not contain_nova_config('database/idle_timeout').with_value('<SERVICE DEFAULT>') }
+      it { is_expected.to_not contain_nova_config('database/connection_recycle_time').with_value('<SERVICE DEFAULT>') }
     end
 
     context 'with overridden database parameters' do
@@ -87,9 +105,9 @@ describe 'nova::scheduler' do
       end
 
       it { is_expected.to contain_oslo__db('nova_config').with(
-        :connection       => 'mysql://user:pass@db/db',
-        :slave_connection => 'mysql://user:pass@slave/db',
-        :idle_timeout     => '30',
+        :connection              => 'mysql://user:pass@db/db',
+        :slave_connection        => 'mysql://user:pass@slave/db',
+        :connection_recycle_time => '30',
       )}
     end
 
